==> arg-services-1.1.0-sources.jar: de/uni_trier/recap/arg_services/mining_explanation/v1beta/AduExplanationServiceGrpc.java <==
package de.uni_trier.recap.arg_services.mining_explanation.v1beta;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.52.1)",
    comments = "Source: arg_services/mining_explanation/v1beta/adu.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class AduExplanationServiceGrpc {

  private AduExplanationServiceGrpc() {}

  public static final String SERVICE_NAME = "arg_services.mining_explanation.v1beta.AduExplanationService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest,
      de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse> getClassificationMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Classification",
      requestType = de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest.class,
      responseType = de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest,
      de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse> getClassificationMethod() {
    io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest, de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse> getClassificationMethod;
    if ((getClassificationMethod = AduExplanationServiceGrpc.getClassificationMethod) == null) {
      synchronized (AduExplanationServiceGrpc.class) {
        if ((getClassificationMethod = AduExplanationServiceGrpc.getClassificationMethod) == null) {
          AduExplanationServiceGrpc.getClassificationMethod = getClassificationMethod =
              io.grpc.MethodDescriptor.<de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest, de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Classification"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse.getDefaultInstance()))
              .setSchemaDescriptor(new AduExplanationServiceMethodDescriptorSupplier("Classification"))
              .build();
        }
      }
    }
    return getClassificationMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static AduExplanationServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AduExplanationServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AduExplanationServiceStub>() {
        @java.lang.Override
        public AduExplanationServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AduExplanationServiceStub(channel, callOptions);
        }
      };
    return AduExplanationServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static AduExplanationServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AduExplanationServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AduExplanationServiceBlockingStub>() {
        @java.lang.Override
        public AduExplanationServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AduExplanationServiceBlockingStub(channel, callOptions);
        }
      };
    return AduExplanationServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static AduExplanationServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AduExplanationServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AduExplanationServiceFutureStub>() {
        @java.lang.Override
        public AduExplanationServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AduExplanationServiceFutureStub(channel, callOptions);
        }
      };
    return AduExplanationServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class AduExplanationServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void classification(de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getClassificationMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getClassificationMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest,
                de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse>(
                  this, METHODID_CLASSIFICATION)))
          .build();
    }
  }

  /**
   */
  public static final class AduExplanationServiceStub extends io.grpc.stub.AbstractAsyncStub<AduExplanationServiceStub> {
    private AduExplanationServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AduExplanationServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AduExplanationServiceStub(channel, callOptions);
    }

    /**
     */
    public void classification(de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getClassificationMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class AduExplanationServiceBlockingStub extends io.grpc.stub.AbstractBlockingStub<AduExplanationServiceBlockingStub> {
    private AduExplanationServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AduExplanationServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AduExplanationServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse classification(de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getClassificationMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class AduExplanationServiceFutureStub extends io.grpc.stub.AbstractFutureStub<AduExplanationServiceFutureStub> {
    private AduExplanationServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AduExplanationServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AduExplanationServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse> classification(
        de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getClassificationMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_CLASSIFICATION = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AduExplanationServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(AduExplanationServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_CLASSIFICATION:
          serviceImpl.classification((de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest) request,
              (io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class AduExplanationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    AduExplanationServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return de.uni_trier.recap.arg_services.mining_explanation.v1beta.AduProto.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("AduExplanationService");
    }
  }

  private static final class AduExplanationServiceFileDescriptorSupplier
      extends AduExplanationServiceBaseDescriptorSupplier {
    AduExplanationServiceFileDescriptorSupplier() {}
  }

  private static final class AduExplanationServiceMethodDescriptorSupplier
      extends AduExplanationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    AduExplanationServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (AduExplanationServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new AduExplanationServiceFileDescriptorSupplier())
              .addMethod(getClassificationMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> arg-services-1.5.9-sources.jar: de/uni_trier/recap/arg_services/mining_explanation/v1beta/AduExplanationServiceGrpc.java <==
package de.uni_trier.recap.arg_services.mining_explanation.v1beta;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.71.0)",
    comments = "Source: arg_services/mining_explanation/v1beta/adu.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class AduExplanationServiceGrpc {

  private AduExplanationServiceGrpc() {}

  public static final java.lang.String SERVICE_NAME = "arg_services.mining_explanation.v1beta.AduExplanationService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest,
      de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse> getClassificationMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Classification",
      requestType = de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest.class,
      responseType = de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest,
      de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse> getClassificationMethod() {
    io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest, de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse> getClassificationMethod;
    if ((getClassificationMethod = AduExplanationServiceGrpc.getClassificationMethod) == null) {
      synchronized (AduExplanationServiceGrpc.class) {
        if ((getClassificationMethod = AduExplanationServiceGrpc.getClassificationMethod) == null) {
          AduExplanationServiceGrpc.getClassificationMethod = getClassificationMethod =
              io.grpc.MethodDescriptor.<de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest, de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Classification"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse.getDefaultInstance()))
              .setSchemaDescriptor(new AduExplanationServiceMethodDescriptorSupplier("Classification"))
              .build();
        }
      }
    }
    return getClassificationMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static AduExplanationServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AduExplanationServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AduExplanationServiceStub>() {
        @java.lang.Override
        public AduExplanationServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AduExplanationServiceStub(channel, callOptions);
        }
      };
    return AduExplanationServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports all types of calls on the service
   */
  public static AduExplanationServiceBlockingV2Stub newBlockingV2Stub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AduExplanationServiceBlockingV2Stub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AduExplanationServiceBlockingV2Stub>() {
        @java.lang.Override
        public AduExplanationServiceBlockingV2Stub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AduExplanationServiceBlockingV2Stub(channel, callOptions);
        }
      };
    return AduExplanationServiceBlockingV2Stub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static AduExplanationServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AduExplanationServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AduExplanationServiceBlockingStub>() {
        @java.lang.Override
        public AduExplanationServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AduExplanationServiceBlockingStub(channel, callOptions);
        }
      };
    return AduExplanationServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static AduExplanationServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AduExplanationServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AduExplanationServiceFutureStub>() {
        @java.lang.Override
        public AduExplanationServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AduExplanationServiceFutureStub(channel, callOptions);
        }
      };
    return AduExplanationServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default void classification(de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getClassificationMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service AduExplanationService.
   */
  public static abstract class AduExplanationServiceImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return AduExplanationServiceGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service AduExplanationService.
   */
  public static final class AduExplanationServiceStub
      extends io.grpc.stub.AbstractAsyncStub<AduExplanationServiceStub> {
    private AduExplanationServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AduExplanationServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AduExplanationServiceStub(channel, callOptions);
    }

    /**
     */
    public void classification(de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getClassificationMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service AduExplanationService.
   */
  public static final class AduExplanationServiceBlockingV2Stub
      extends io.grpc.stub.AbstractBlockingStub<AduExplanationServiceBlockingV2Stub> {
    private AduExplanationServiceBlockingV2Stub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AduExplanationServiceBlockingV2Stub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AduExplanationServiceBlockingV2Stub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse classification(de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getClassificationMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do limited synchronous rpc calls to service AduExplanationService.
   */
  public static final class AduExplanationServiceBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<AduExplanationServiceBlockingStub> {
    private AduExplanationServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AduExplanationServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AduExplanationServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse classification(de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getClassificationMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service AduExplanationService.
   */
  public static final class AduExplanationServiceFutureStub
      extends io.grpc.stub.AbstractFutureStub<AduExplanationServiceFutureStub> {
    private AduExplanationServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AduExplanationServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AduExplanationServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse> classification(
        de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getClassificationMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_CLASSIFICATION = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_CLASSIFICATION:
          serviceImpl.classification((de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest) request,
              (io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getClassificationMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationRequest,
              de.uni_trier.recap.arg_services.mining_explanation.v1beta.ClassificationResponse>(
                service, METHODID_CLASSIFICATION)))
        .build();
  }

  private static abstract class AduExplanationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    AduExplanationServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return de.uni_trier.recap.arg_services.mining_explanation.v1beta.AduProto.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("AduExplanationService");
    }
  }

  private static final class AduExplanationServiceFileDescriptorSupplier
      extends AduExplanationServiceBaseDescriptorSupplier {
    AduExplanationServiceFileDescriptorSupplier() {}
  }

  private static final class AduExplanationServiceMethodDescriptorSupplier
      extends AduExplanationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    AduExplanationServiceMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (AduExplanationServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new AduExplanationServiceFileDescriptorSupplier())
              .addMethod(getClassificationMethod())
              .build();
        }
      }
    }
    return result;
  }
}
